@@ -9,6 +9,7 @@ from mkdocs_git_revision_date_localized_plugin.ci import raise_ci_warnings
 from babel.dates import format_date, get_timezone
 from git import (
     Repo,
+    Git,
     GitCommandError,
     GitCommandNotFound,
     InvalidGitRepositoryError,
@@ -28,11 +29,10 @@ class Util:
 
     def __init__(self, config={}):
         """Initialize utility class."""
-        self.fallback_enabled = False
         self.config = config
         self.repo_cache = {}
 
-    def _get_repo(self, path: str):
+    def _get_repo(self, path: str) -> Git:
         if not os.path.isdir(path):
             path = os.path.dirname(path)
 
@@ -78,41 +78,48 @@ class Util:
             % (loc_revision_date.isoformat(), locale),
         }
 
-    def get_revision_date_for_file(
-        self,
-        path: str,
-        locale: str = "en",
-        time_zone: str = "UTC",
-        fallback_to_build_date: bool = False,
-    ) -> Dict[str, str]:
+    def get_git_commit_timestamp(
+            self,
+            path: str,
+            is_first_commit: bool = False
+    ) -> int:
         """
-        Determine localized date variants for a given file.
+        Get a list of commit dates in unix timestamp, starts with the most recent commit.
 
         Args:
+            is_first_commit (bool): if true, get the timestamp of the first commit,
+                                    else, get that of the most recent commit.
             path (str): Location of a markdown file that is part of a Git repository.
-            locale (str, optional): Locale code of language to use. Defaults to 'en'.
-            timezone (str): Timezone database name (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
+            is_first_commit (bool): retrieve commit timestamp when file was created.
 
         Returns:
-            dict: Localized date variants.
+            int: commit date in unix timestamp, starts with the most recent commit.
         """
-        unix_timestamp = None
+        commit_timestamp = ""
 
         # perform git log operation
         try:
-            if not self.fallback_enabled:
-                # Retrieve author date in UNIX format (%at)
-                # https://git-scm.com/docs/git-log#Documentation/git-log.txt-ematem
-                realpath = os.path.realpath(path)
-                unix_timestamp = self._get_repo(realpath).log(
-                    realpath, n=1, date="short", format="%at"
+            # Retrieve author date in UNIX format (%at)
+            # https://git-scm.com/docs/git-log#Documentation/git-log.txt-ematem
+            # https://git-scm.com/docs/git-log#Documentation/git-log.txt---diff-filterACDMRTUXB82308203
+            realpath = os.path.realpath(path)
+            git = self._get_repo(realpath)
+            if is_first_commit:
+                # diff_filter="A" will select the commit that created the file
+                commit_timestamp = git.log(
+                    realpath, date="short", format="%at", diff_filter="A"
+                )
+            else:
+                commit_timestamp = git.log(
+                    realpath, date="short", format="%at", n=1
                 )
         except (InvalidGitRepositoryError, NoSuchPathError) as err:
-            if fallback_to_build_date:
+            if self.config.get('fallback_to_build_date'):
                 logger.warning(
                     "[git-revision-date-localized-plugin] Unable to find a git directory and/or git is not installed."
                     " Option 'fallback_to_build_date' set to 'true': Falling back to build date"
                 )
+                commit_timestamp = time.time()
             else:
                 logger.error(
                     "[git-revision-date-localized-plugin] Unable to find a git directory and/or git is not installed."
@@ -120,12 +127,13 @@ class Util:
                 )
                 raise err
         except GitCommandError as err:
-            if fallback_to_build_date:
+            if self.config.get('fallback_to_build_date'):
                 logger.warning(
                     "[git-revision-date-localized-plugin] Unable to read git logs of '%s'. Is git log readable?"
                     " Option 'fallback_to_build_date' set to 'true': Falling back to build date"
                     % path
                 )
+                commit_timestamp = time.time()
             else:
                 logger.error(
                     "[git-revision-date-localized-plugin] Unable to read git logs of '%s'. "
@@ -134,11 +142,12 @@ class Util:
                 )
                 raise err
         except GitCommandNotFound as err:
-            if fallback_to_build_date:
+            if self.config.get('fallback_to_build_date'):
                 logger.warning(
                     "[git-revision-date-localized-plugin] Unable to perform command: 'git log'. Is git installed?"
                     " Option 'fallback_to_build_date' set to 'true': Falling back to build date"
                 )
+                commit_timestamp = time.time()
             else:
                 logger.error(
                     "[git-revision-date-localized-plugin] Unable to perform command 'git log'. Is git installed?"
@@ -147,16 +156,35 @@ class Util:
                 raise err
 
         # create timestamp
-        if not unix_timestamp:
-            unix_timestamp = time.time()
-            if not self.fallback_enabled:
-                logger.warning(
-                    "[git-revision-date-localized-plugin] '%s' has no git logs, using current timestamp"
-                    % path
-                )
+        if commit_timestamp == "":
+            commit_timestamp = time.time()
+            logger.warning(
+                "[git-revision-date-localized-plugin] '%s' has no git logs, using current timestamp"
+                % path
+            )
+
+        return int(commit_timestamp)
+
+    def get_date_formats_for_timestamp(
+        self,
+        commit_timestamp: int,
+    ) -> Dict[str, str]:
+        """
+        Determine localized date variants for a given file.
+
+        Args:
+            commit_timestamp (int): most recent commit date in unix timestamp.
+            locale (str, optional): Locale code of language to use. Defaults to 'en'.
+            time_zone (str): Timezone database name (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
+
+        Returns:
+            dict: Localized date variants.
+        """
 
         date_formats = self._date_formats(
-            unix_timestamp=unix_timestamp, time_zone=time_zone, locale=locale
+            unix_timestamp=commit_timestamp, 
+            time_zone=self.config.get("time_zone"),
+            locale=self.config.get("locale")
         )
 
         # Wrap in <span> for styling
@@ -167,3 +195,4 @@ class Util:
             )
 
         return date_formats
+
